package user

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// GetRequest struct to check if the inviteusertoken and emailaddress pair are valid and matching.
type IsValidInviteUserTokenRequest struct {
	// InviteUserToken
	// The token that was previously sent to the invited user email
	// Required: true
	InviteUserToken string `url:"inviteusertoken" json:"inviteusertoken" validate:"required"`

	// EmailAddress
	// Email address for the user
	// Required: true
	EmailAddress string `url:"emailaddress" json:"emailaddress" validate:"required"`
}

// IsValidInviteUserToken checks if the inviteusertoken and emailaddress pair are valid and matching.
func (u User) IsValidInviteUserToken(ctx context.Context, req IsValidInviteUserTokenRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudapi/user/isValidInviteUserToken"

	res, err := u.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
