package vfpool

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// GetRequest struct to get detailed information about vfpool device
type GetRequest struct {
	// ID of vfpool device
	// Required: true
	VFPoolID uint64 `url:"id" json:"id" validate:"required"`
}

// Get gets detailed information about vfpool device as a RecordVFPool struct
func (v VFPool) Get(ctx context.Context, req GetRequest) (*RecordVFPool, error) {
	res, err := v.GetRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	info := RecordVFPool{}

	err = json.Unmarshal(res, &info)
	if err != nil {
		return nil, err
	}

	return &info, nil
}

// GetRaw gets detailed information about vfpool device as an array of bytes
func (v VFPool) GetRaw(ctx context.Context, req GetRequest) ([]byte, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudapi/vfpool/get"

	res, err := v.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
