package image

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// GrantAccessRequest struct to share image with accounts
type GrantAccessRequest struct {
	// ID of the image to share
	// Required: true
	ImageID uint64 `url:"imageId" json:"imageId" validate:"required"`

	// ID of the accounts for share image
	// Required: true
	AccountIDs []uint64 `url:"accounts" json:"accounts" validate:"required"`
}

// GrantAccess shares specified image with specified accounts
func (i Image) GrantAccess(ctx context.Context, req GrantAccessRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/image/grantAccess"

	res, err := i.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
